@@ -18,7 +18,7 @@ class TQWidget;
 #include <tqobject.h>
 
 // KDE includes
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 // Project includes
 
