@@ -20,9 +20,9 @@
 #include <tqptrlist.h>
 #include <tqvaluelist.h>
 // KDE includes
-// #include <kparts>
-#include <kparts/part.h>
-#include <kparts/mainwindow.h>
+// #include <tdeparts>
+#include <tdeparts/part.h>
+#include <tdeparts/mainwindow.h>
 
 class TQObject;
 namespace KMF {
