@@ -37,10 +37,10 @@
 
 // KDE includes
 #include <kdebug.h>
-#include <klocale.h>
-#include <klistview.h>
+#include <tdelocale.h>
+#include <tdelistview.h>
 #include <kcombobox.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kiconloader.h>
 #include <kinputdialog.h>
 #include <knuminput.h>
@@ -64,7 +64,7 @@
 namespace KMF {
 KMFGenericInterfaceProtocol::KMFGenericInterfaceProtocol( TQWidget *parent, const char *name, WFlags f ) : KMyFirewallGenericInterfaceProtocolWidget( parent, name, f ) {
 	loadIcons();
-	m_contextMenu = new KPopupMenu( this, "m_contextMenu" );
+	m_contextMenu = new TDEPopupMenu( this, "m_contextMenu" );
 //	m_lv_protocols->setFullWidth( true );
 	
 	// Network Widget
@@ -613,69 +613,69 @@ void KMFGenericInterfaceProtocol::slotRenameItem( TQListViewItem* item, int, con
  
 void KMFGenericInterfaceProtocol::loadIcons() {
 	kdDebug() << "void KMFGenericInterfa::loadIcons()" << endl;
-	KIconLoader *loader = KGlobal:: iconLoader();
+	TDEIconLoader *loader = TDEGlobal:: iconLoader();
 	TQString icon_name;
 
-	icon_name = "up";
-	icon_up = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-up";
+	icon_up = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "down";
-	icon_down = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-down";
+	icon_down = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editdelete";
-	icon_del = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-delete";
+	icon_del = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filenew";
-	icon_new = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-new";
+	icon_new = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "edit";
-	icon_edit = loader->loadIcon( icon_name, KIcon::Small );
+	icon_edit = loader->loadIcon( icon_name, TDEIcon::Small );
 
 
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "text";
-	icon_rename = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rename = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "rule-22";
-	icon_rule = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rule = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "view_tree";
-	icon_chain = loader->loadIcon( icon_name, KIcon::Small );
+	icon_chain = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "reject";
-	icon_reject = loader->loadIcon( icon_name, KIcon::User );
+	icon_reject = loader->loadIcon( icon_name, TDEIcon::User );
 
 	icon_name = "target";
-	icon_target = loader->loadIcon( icon_name, KIcon::User );
+	icon_target = loader->loadIcon( icon_name, TDEIcon::User );
 
-	icon_name = "stop";
-	icon_drop = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "process-stop";
+	icon_drop = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "button_ok";
-	icon_accept = loader->loadIcon( icon_name, KIcon::Small );
+	icon_accept = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filesaveas";
-	icon_log = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-save-as";
+	icon_log = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "undo";
-	icon_return = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-undo";
+	icon_return = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editclear";
-	icon_cmd = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-clear";
+	icon_cmd = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "pipe";
-	icon_queue = loader->loadIcon( icon_name, KIcon::Small );
+	icon_queue = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editcopy";
-	icon_copy = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-copy";
+	icon_copy = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "forward";
-	icon_move = loader->loadIcon( icon_name, KIcon::Small );
+	icon_move = loader->loadIcon( icon_name, TDEIcon::Small );
 
 }
 
