@@ -407,7 +407,7 @@ void KMFConfigDialog::loadIcons() {
 	icon_name = "view_tree";
 	icon_listview = loader->loadIcon( icon_name, TDEIcon::Desktop );
 	
-	icon_name = "nfs_unmount";
+	icon_name = "nfs-unmounted";
 	icon_edit_protocol_page = loader->loadIcon( icon_name, TDEIcon::Desktop );
 }
 
