@@ -17,8 +17,8 @@
 
 #include <tqwidget.h>
 #include <kdialogbase.h>
-#include <kconfig.h>
-#include <kglobal.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
 #include <kprocess.h>
 #include <tqstring.h>
 #include <tqpixmap.h>
@@ -30,7 +30,7 @@ class KMFTarget;
 class KMFHostWidget : public KMyFirewallHostWidget
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
 public:
 	KMFHostWidget(TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
