@@ -22,7 +22,7 @@
 #ifndef KMFMAINWINDOW_H
 #define KMFMAINWINDOW_H
 
-#include <kparts/mainwindow.h>
+#include <tdeparts/mainwindow.h>
 #include "../core/kmyfirewallinterface.h"
 #include "../core/netfilterobject.h"
 
@@ -33,7 +33,7 @@
 namespace KMF {
 class KDE_EXPORT KMFMainWindow : public KParts::MainWindow, virtual public KMyFirewallInterface {
 	Q_OBJECT
-  TQ_OBJECT
+  
 public:
 
 	KMFMainWindow( TQWidget* parent, const char *name );
