@@ -25,11 +25,11 @@
 // KDe Includes
 #include <ktabwidget.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kglobal.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <kinputdialog.h>
 
 // Project includes
@@ -52,7 +52,7 @@ KMFMyNetworkWidget::KMFMyNetworkWidget(TQWidget* parent, const char* name, WFlag
 {
 	kdDebug() << "Contructor: KMFMyNetworkWidget::KMFMyNetworkWidget(TQWidget* parent, const char* name, WFlags fl)" << endl;
 	m_network = 0;
-	m_contextMenu = new KPopupMenu( this, "m_contextMenu" );
+	m_contextMenu = new TDEPopupMenu( this, "m_contextMenu" );
 
 	connect( m_lv_zones, TQT_SIGNAL( contextMenuRequested ( TQListViewItem*, const TQPoint&, int ) ),
 			 this, TQT_SLOT( slotZoneRBM( TQListViewItem*, const TQPoint&, int ) ) );
@@ -265,7 +265,7 @@ void KMFMyNetworkWidget::slotZoneRBM( TQListViewItem* item, const TQPoint& point
 			}
 			if ( ! m_target->isCurrentTarget() ) {
 				m_contextMenu->insertSeparator();
-				m_contextMenu->insertItem( KGlobal::iconLoader()->loadIcon( "kmyfirewall", KIcon::Small ), i18n( "Make Active Target..." ), this, TQT_SLOT( slotSetActiveTarget() ) );
+				m_contextMenu->insertItem( TDEGlobal::iconLoader()->loadIcon( "kmyfirewall", TDEIcon::Small ), i18n( "Make Active Target..." ), this, TQT_SLOT( slotSetActiveTarget() ) );
 			}
 			
 			m_contextMenu->popup( point );
@@ -513,69 +513,69 @@ KMFListViewItem* KMFMyNetworkWidget::findItem( const TQUuid& obj_id ) {
 /*$SPECIALIZATION$*/
 void KMFMyNetworkWidget::loadIcons() {
 	kdDebug() << "void KMFGenericInterfa::loadIcons()" << endl;
-	KIconLoader *loader = KGlobal:: iconLoader();
+	TDEIconLoader *loader = TDEGlobal:: iconLoader();
 	TQString icon_name;
 
-	icon_name = "up";
-	icon_up = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-up";
+	icon_up = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "down";
-	icon_down = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "go-down";
+	icon_down = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editdelete";
-	icon_del = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-delete";
+	icon_del = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filenew";
-	icon_new = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-new";
+	icon_new = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "edit";
-	icon_edit = loader->loadIcon( icon_name, KIcon::Small );
+	icon_edit = loader->loadIcon( icon_name, TDEIcon::Small );
 
 
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "text";
-	icon_rename = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rename = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "rule-22";
-	icon_rule = loader->loadIcon( icon_name, KIcon::Small );
+	icon_rule = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "view_tree";
-	icon_chain = loader->loadIcon( icon_name, KIcon::Small );
+	icon_chain = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "reject";
-	icon_reject = loader->loadIcon( icon_name, KIcon::User );
+	icon_reject = loader->loadIcon( icon_name, TDEIcon::User );
 
 	icon_name = "target";
-	icon_target = loader->loadIcon( icon_name, KIcon::User );
+	icon_target = loader->loadIcon( icon_name, TDEIcon::User );
 
-	icon_name = "stop";
-	icon_drop = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "process-stop";
+	icon_drop = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "button_ok";
-	icon_accept = loader->loadIcon( icon_name, KIcon::Small );
+	icon_accept = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "filesaveas";
-	icon_log = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "document-save-as";
+	icon_log = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "undo";
-	icon_return = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-undo";
+	icon_return = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editclear";
-	icon_cmd = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-clear";
+	icon_cmd = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "filter";
-	icon_filter = loader->loadIcon( icon_name, KIcon::Small );
+	icon_filter = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "pipe";
-	icon_queue = loader->loadIcon( icon_name, KIcon::Small );
+	icon_queue = loader->loadIcon( icon_name, TDEIcon::Small );
 
-	icon_name = "editcopy";
-	icon_copy = loader->loadIcon( icon_name, KIcon::Small );
+	icon_name = "edit-copy";
+	icon_copy = loader->loadIcon( icon_name, TDEIcon::Small );
 
 	icon_name = "forward";
-	icon_move = loader->loadIcon( icon_name, KIcon::Small );
+	icon_move = loader->loadIcon( icon_name, TDEIcon::Small );
 
 }
 
