@@ -17,11 +17,11 @@
 
 #include "kmyfirewalltransactionlog.h"
 
-class KPopupMenu;
-class KProcess;
+class TDEPopupMenu;
+class TDEProcess;
 class KTempFile;
-class KListView;
-class KListViewItem;
+class TDEListView;
+class TDEListViewItem;
 
 namespace KMF {
 class KMFTransaction;
@@ -30,7 +30,7 @@ class KMFTransaction;
 class KMFTransactionLog : public KMyFirewallTransactionLog
 {
 		Q_OBJECT
-  TQ_OBJECT
+  
 	
 	public: static KMFTransactionLog* instance();
 	
@@ -54,14 +54,14 @@ class KMFTransactionLog : public KMyFirewallTransactionLog
 		void slotLog( const TQString& );
 		void slotZoneRBM( TQListViewItem*, const TQPoint&, int );
 		void slotShowDiff();
-		void slotKompareExited( KProcess* );	
+		void slotKompareExited( TDEProcess* );	
 	private:
 		KMFTransactionLog ( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
-		KListViewItem* setupListItem( KMFTransaction*, KListView*, KListViewItem*);
+		TDEListViewItem* setupListItem( KMFTransaction*, TDEListView*, TDEListViewItem*);
 		
 	// DATA
 	private: 
-		KPopupMenu *m_contextMenu;
+		TDEPopupMenu *m_contextMenu;
 		KMFTransaction* m_currentTransaction;
 		KTempFile *m_undoXMLFile;
 		KTempFile *m_redoXMLFile;
